pub enum BoundListenAddress {
Tcp(SocketAddr),
Udp(SocketAddr),
Unixgram(PathBuf),
Unix(PathBuf),
NamedPipe(String),
}Expand description
A bound listen address.
This represents the “local” address of a listener (whether Listener or
ConnectionOrientedListener), and is reciprocal to
ListenAddress, containing the same exact variants. This type is meant to be published as a dataspace assertion
when a server binds to a particular ListenAddress, providing the resolved address, such as the exact port used
for a TCP/UDP socket when an ephemeral port was originally specified, and so on.
Variants
Tcp(SocketAddr)
A TCP listen address.
Udp(SocketAddr)
A UDP listen address.
Unixgram(PathBuf)
A Unix datagram listen address.
Unix(PathBuf)
A Unix stream listen address.
NamedPipe(String)
A Windows named pipe listen address.