pub enum ProcessIdentity {
Credentials(ProcessCredentials),
Error(ProcessCredentialsError),
Unavailable,
}Expand description
Process identity associated with a Unix domain socket peer.
Variants
Credentials(ProcessCredentials)
Process credentials were detected.
Error(ProcessCredentialsError)
Process credential detection failed.
Process identity isn’t available for this peer.
Implementations
Sourceimpl ProcessIdentity
impl ProcessIdentity
Sourcepub fn credentials(&self) -> Option<&ProcessCredentials>
pub fn credentials(&self) -> Option<&ProcessCredentials>
Returns process credentials, if they were detected.
Sourcepub const fn is_telemetry_error(&self) -> bool
pub const fn is_telemetry_error(&self) -> bool
Returns true if process credential detection failed for a per-message reason.